window.Gleam.initSearch([{"doc":"gleam_yielder","title":"gleam_yielder","content":"# Yielder\n\nUnfold values on-demand from a function.\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_yielder)](https://hex.pm/packages/gleam_yielder)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_yielder/)\n\n\nYou may want to use this library when you have a function that can generate a\nsequence of values but the sequence is too large to fit into memory, or it would\nbe wasteful to do so. You could instead create a `Yielder` for it and only have\nthe section you are working on in memory, and halt evaluation when you have\nconsumed as much of the sequence as you need for your program.\n```sh\ngleam add gleam_yielder@1\n```\n```gleam\nimport gleam/yielder\n\npub fn main() {\n  yielder.unfold(2, fn(acc) { yielder.Next(acc, acc * 2) })\n  |&gt; yielder.take(5)\n  |&gt; yielder.to_list\n  // -&gt; [2, 4, 8, 16, 32]\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleam_yielder&gt;.\n","url":"index.html"},{"doc":"gleam/yielder","title":"Step","content":"pub type Step(element, accumulator) {\n  Next(element: element, accumulator: accumulator)\n  Done\n}\n\nNext(element: element, accumulator: accumulator)\n\n\nDone\n\n\nSynonyms:\ngleam/yielder.Step\ngleam/yielder Step","url":"gleam/yielder.html#Step"},{"doc":"gleam/yielder","title":"Yielder","content":"pub opaque type Yielder(element)\n An yielder is a lazily evaluated sequence of element.\n\n Yielders are useful when working with collections that are too large to\n fit in memory (or those that are infinite in size) as they only require the\n elements currently being processed to be in memory.\n\n As a lazy data structure no work is done when an yielder is filtered,\n mapped, etc, instead a new yielder is returned with these transformations\n applied to the stream. Once the stream has all the required transformations\n applied it can be evaluated using functions such as `fold` and `to_list`.\n\n\nSynonyms:\ngleam/yielder.Yielder\ngleam/yielder Yielder","url":"gleam/yielder.html#Yielder"},{"doc":"gleam/yielder","title":"all","content":"pub fn all(\n  in yielder: Yielder(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if all elements emitted by the yielder satisfy the given predicate,\n `False` otherwise.\n\n This function short-circuits once it finds a non-satisfying element.\n\n An empty yielder results in `True`.\n\n ## Examples\n\n \n empty()\n |&gt; all(fn(n) { n % 2 == 0 })\n // -&gt; True\n \n\n \n from_list([2, 4, 6, 8])\n |&gt; all(fn(n) { n % 2 == 0 })\n // -&gt; True\n \n\n \n from_list([2, 4, 5, 8])\n |&gt; all(fn(n) { n % 2 == 0 })\n // -&gt; False\n \n\nSynonyms:\ngleam/yielder.all\ngleam/yielder all","url":"gleam/yielder.html#all"},{"doc":"gleam/yielder","title":"any","content":"pub fn any(\n  in yielder: Yielder(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if any element emitted by the yielder satisfies the given predicate,\n `False` otherwise.\n\n This function short-circuits once it finds a satisfying element.\n\n An empty yielder results in `False`.\n\n ## Examples\n\n \n empty()\n |&gt; any(fn(n) { n % 2 == 0 })\n // -&gt; False\n \n\n \n from_list([1, 2, 5, 7, 9])\n |&gt; any(fn(n) { n % 2 == 0 })\n // -&gt; True\n \n\n \n from_list([1, 3, 5, 7, 9])\n |&gt; any(fn(n) { n % 2 == 0 })\n // -&gt; False\n \n\nSynonyms:\ngleam/yielder.any\ngleam/yielder any","url":"gleam/yielder.html#any"},{"doc":"gleam/yielder","title":"append","content":"pub fn append(\n  to first: Yielder(a),\n  suffix second: Yielder(a),\n) -&gt; Yielder(a)\n Appends two yielders, producing a new yielder.\n\n This function does not evaluate the elements of the yielders, the\n computation is performed when the resulting yielder is later run.\n\n ## Examples\n\n \n from_list([1, 2])\n |&gt; append(from_list([3, 4]))\n |&gt; to_list\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/yielder.append\ngleam/yielder append","url":"gleam/yielder.html#append"},{"doc":"gleam/yielder","title":"at","content":"pub fn at(\n  in yielder: Yielder(a),\n  get index: Int,\n) -&gt; Result(a, Nil)\n Returns nth element yielded by the given yielder, where `0` means the first element.\n\n If there are not enough elements in the yielder, `Error(Nil)` is returned.\n\n For any `index` less than `0` this function behaves as if it was set to `0`.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4]) |&gt; at(2)\n // -&gt; Ok(3)\n \n\n \n from_list([1, 2, 3, 4]) |&gt; at(4)\n // -&gt; Error(Nil)\n \n\n \n empty() |&gt; at(0)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/yielder.at\ngleam/yielder at","url":"gleam/yielder.html#at"},{"doc":"gleam/yielder","title":"chunk","content":"pub fn chunk(\n  over yielder: Yielder(a),\n  by f: fn(a) -&gt; b,\n) -&gt; Yielder(List(a))\n Creates an yielder that emits chunks of elements\n for which `f` returns the same value.\n\n ## Examples\n\n \n from_list([1, 2, 2, 3, 4, 4, 6, 7, 7])\n |&gt; chunk(by: fn(n) { n % 2 })\n |&gt; to_list\n // -&gt; [[1], [2, 2], [3], [4, 4, 6], [7, 7]]\n \n\nSynonyms:\ngleam/yielder.chunk\ngleam/yielder chunk","url":"gleam/yielder.html#chunk"},{"doc":"gleam/yielder","title":"concat","content":"pub fn concat(yielders: List(Yielder(a))) -&gt; Yielder(a)\n Joins a list of yielders into a single yielder.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n [[1, 2], [3, 4]]\n |&gt; map(from_list)\n |&gt; concat\n |&gt; to_list\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/yielder.concat\ngleam/yielder concat","url":"gleam/yielder.html#concat"},{"doc":"gleam/yielder","title":"cycle","content":"pub fn cycle(yielder: Yielder(a)) -&gt; Yielder(a)\n Creates an yielder that repeats a given yielder infinitely.\n\n ## Examples\n\n \n from_list([1, 2])\n |&gt; cycle\n |&gt; take(6)\n |&gt; to_list\n // -&gt; [1, 2, 1, 2, 1, 2]\n \n\nSynonyms:\ngleam/yielder.cycle\ngleam/yielder cycle","url":"gleam/yielder.html#cycle"},{"doc":"gleam/yielder","title":"drop","content":"pub fn drop(\n  from yielder: Yielder(a),\n  up_to desired: Int,\n) -&gt; Yielder(a)\n Evaluates and discards the first N elements in an yielder, returning a new\n yielder.\n\n If the yielder does not have enough elements an empty yielder is\n returned.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 5])\n |&gt; drop(up_to: 3)\n |&gt; to_list\n // -&gt; [4, 5]\n \n\n \n from_list([1, 2])\n |&gt; drop(up_to: 3)\n |&gt; to_list\n // -&gt; []\n \n\nSynonyms:\ngleam/yielder.drop\ngleam/yielder drop","url":"gleam/yielder.html#drop"},{"doc":"gleam/yielder","title":"drop_while","content":"pub fn drop_while(\n  in yielder: Yielder(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Yielder(a)\n Creates an yielder that drops elements while the predicate returns `True`,\n and then yields the remaining elements.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 2, 5])\n |&gt; drop_while(satisfying: fn(x) { x &lt; 4 })\n |&gt; to_list\n // -&gt; [4, 2, 5]\n \n\nSynonyms:\ngleam/yielder.drop_while\ngleam/yielder drop_while","url":"gleam/yielder.html#drop_while"},{"doc":"gleam/yielder","title":"each","content":"pub fn each(over yielder: Yielder(a), with f: fn(a) -&gt; b) -&gt; Nil\n Traverse an yielder, calling a function on each element.\n\n ## Examples\n\n \n empty() |&gt; each(io.println)\n // -&gt; Nil\n \n\n \n from_list([&quot;Tom&quot;, &quot;Malory&quot;, &quot;Louis&quot;]) |&gt; each(io.println)\n // -&gt; Nil\n // Tom\n // Malory\n // Louis\n \n\nSynonyms:\ngleam/yielder.each\ngleam/yielder each","url":"gleam/yielder.html#each"},{"doc":"gleam/yielder","title":"empty","content":"pub fn empty() -&gt; Yielder(a)\n Creates an yielder that yields no elements.\n\n ## Examples\n\n \n empty() |&gt; to_list\n // -&gt; []\n \n\nSynonyms:\ngleam/yielder.empty\ngleam/yielder empty","url":"gleam/yielder.html#empty"},{"doc":"gleam/yielder","title":"filter","content":"pub fn filter(\n  yielder: Yielder(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Yielder(a)\n Creates an yielder from an existing yielder and a predicate function.\n\n The new yielder will contain elements from the first yielder for which\n the given function returns `True`.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n import gleam/int\n\n from_list([1, 2, 3, 4])\n |&gt; filter(int.is_even)\n |&gt; to_list\n // -&gt; [2, 4]\n \n\nSynonyms:\ngleam/yielder.filter\ngleam/yielder filter","url":"gleam/yielder.html#filter"},{"doc":"gleam/yielder","title":"filter_map","content":"pub fn filter_map(\n  yielder: Yielder(a),\n  keeping_with f: fn(a) -&gt; Result(b, c),\n) -&gt; Yielder(b)\n Creates an yielder from an existing yielder and a transforming predicate function.\n\n The new yielder will contain elements from the first yielder for which\n the given function returns `Ok`, transformed to the value inside the `Ok`.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n import gleam/string\n import gleam/int\n\n &quot;a1b2c3d4e5f&quot;\n |&gt; string.to_graphemes\n |&gt; from_list\n |&gt; filter_map(int.parse)\n |&gt; to_list\n // -&gt; [1, 2, 3, 4, 5]\n \n\nSynonyms:\ngleam/yielder.filter_map\ngleam/yielder filter_map","url":"gleam/yielder.html#filter_map"},{"doc":"gleam/yielder","title":"find","content":"pub fn find(\n  in haystack: Yielder(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Finds the first element in a given yielder for which the given function returns\n `True`.\n\n Returns `Error(Nil)` if the function does not return `True` for any of the\n elements.\n\n ## Examples\n\n \n find(from_list([1, 2, 3]), fn(x) { x &gt; 2 })\n // -&gt; Ok(3)\n \n\n \n find(from_list([1, 2, 3]), fn(x) { x &gt; 4 })\n // -&gt; Error(Nil)\n \n\n \n find(empty(), fn(_) { True })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/yielder.find\ngleam/yielder find","url":"gleam/yielder.html#find"},{"doc":"gleam/yielder","title":"find_map","content":"pub fn find_map(\n  in haystack: Yielder(a),\n  one_that is_desired: fn(a) -&gt; Result(b, c),\n) -&gt; Result(b, Nil)\n Finds the first element in a given yielder\n for which the given function returns `Ok(new_value)`,\n then returns the wrapped `new_value`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n find_map(from_list([&quot;a&quot;, &quot;1&quot;, &quot;2&quot;]), int.parse)\n // -&gt; Ok(1)\n \n\n \n find_map(from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]), int.parse)\n // -&gt; Error(Nil)\n \n\n \n find_map(from_list([]), int.parse)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/yielder.find_map\ngleam/yielder find_map","url":"gleam/yielder.html#find_map"},{"doc":"gleam/yielder","title":"first","content":"pub fn first(from yielder: Yielder(a)) -&gt; Result(a, Nil)\n Returns the first element yielded by the given yielder, if it exists,\n or `Error(Nil)` otherwise.\n\n ## Examples\n\n \n from_list([1, 2, 3]) |&gt; first\n // -&gt; Ok(1)\n \n\n \n empty() |&gt; first\n // -&gt; Error(Nil)\n \nSynonyms:\ngleam/yielder.first\ngleam/yielder first","url":"gleam/yielder.html#first"},{"doc":"gleam/yielder","title":"flat_map","content":"pub fn flat_map(\n  over yielder: Yielder(a),\n  with f: fn(a) -&gt; Yielder(b),\n) -&gt; Yielder(b)\n Creates an yielder from an existing yielder and a transformation function.\n\n Each element in the new yielder will be the result of calling the given\n function on the elements in the given yielder and then flattening the\n results.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n from_list([1, 2])\n |&gt; flat_map(fn(x) { from_list([x, x + 1]) })\n |&gt; to_list\n // -&gt; [1, 2, 2, 3]\n \n\nSynonyms:\ngleam/yielder.flat_map\ngleam/yielder flat_map","url":"gleam/yielder.html#flat_map"},{"doc":"gleam/yielder","title":"flatten","content":"pub fn flatten(yielder: Yielder(Yielder(a))) -&gt; Yielder(a)\n Flattens an yielder of yielders, creating a new yielder.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n from_list([[1, 2], [3, 4]])\n |&gt; map(from_list)\n |&gt; flatten\n |&gt; to_list\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/yielder.flatten\ngleam/yielder flatten","url":"gleam/yielder.html#flatten"},{"doc":"gleam/yielder","title":"fold","content":"pub fn fold(\n  over yielder: Yielder(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces an yielder of elements into a single value by calling a given\n function on each element in turn.\n\n If called on an yielder of infinite length then this function will never\n return.\n\n If you do not care about the end value and only wish to evaluate the\n yielder for side effects consider using the `run` function instead.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; fold(from: 0, with: fn(acc, element) { element + acc })\n // -&gt; 10\n \n\nSynonyms:\ngleam/yielder.fold\ngleam/yielder fold","url":"gleam/yielder.html#fold"},{"doc":"gleam/yielder","title":"fold_until","content":"pub fn fold_until(\n  over yielder: Yielder(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; ContinueOrStop(b),\n) -&gt; b\n Like `fold`, `fold_until` reduces an yielder of elements into a single value by calling a given\n function on each element in turn, but uses `list.ContinueOrStop` to determine\n whether or not to keep iterating.\n\n If called on an yielder of infinite length then this function will only ever\n return if the function returns `list.Stop`.\n\n ## Examples\n\n \n import gleam/list\n\n let f = fn(acc, e) {\n   case e {\n     _ if e &lt; 4 -&gt; list.Continue(e + acc)\n     _ -&gt; list.Stop(acc)\n   }\n }\n\n from_list([1, 2, 3, 4])\n |&gt; fold_until(from: 0, with: f)\n // -&gt; 6\n \n\nSynonyms:\ngleam/yielder.fold_until\ngleam/yielder fold_until","url":"gleam/yielder.html#fold_until"},{"doc":"gleam/yielder","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Yielder(a)\n Creates an yielder that yields each element from the given list.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; to_list\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/yielder.from_list\ngleam/yielder from_list","url":"gleam/yielder.html#from_list"},{"doc":"gleam/yielder","title":"group","content":"pub fn group(\n  in yielder: Yielder(a),\n  by key: fn(a) -&gt; b,\n) -&gt; Dict(b, List(a))\n Returns a `Dict(k, List(element))` of elements from the given yielder\n grouped with the given key function.\n\n The order within each group is preserved from the yielder.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 5, 6])\n |&gt; group(by: fn(n) { n % 3 })\n // -&gt; dict.from_list([#(0, [3, 6]), #(1, [1, 4]), #(2, [2, 5])])\n \n\nSynonyms:\ngleam/yielder.group\ngleam/yielder group","url":"gleam/yielder.html#group"},{"doc":"gleam/yielder","title":"index","content":"pub fn index(over yielder: Yielder(a)) -&gt; Yielder(#(a, Int))\n Wraps values yielded from an yielder with indices, starting from 0.\n\n ## Examples\n\n \n from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]) |&gt; index |&gt; to_list\n // -&gt; [#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;c&quot;, 2)]\n \n\nSynonyms:\ngleam/yielder.index\ngleam/yielder index","url":"gleam/yielder.html#index"},{"doc":"gleam/yielder","title":"interleave","content":"pub fn interleave(\n  left: Yielder(a),\n  with right: Yielder(a),\n) -&gt; Yielder(a)\n Creates an yielder that alternates between the two given yielders\n until both have run out.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; interleave(from_list([11, 12, 13, 14]))\n |&gt; to_list\n // -&gt; [1, 11, 2, 12, 3, 13, 4, 14]\n \n\n \n from_list([1, 2, 3, 4])\n |&gt; interleave(from_list([100]))\n |&gt; to_list\n // -&gt; [1, 100, 2, 3, 4]\n \n\nSynonyms:\ngleam/yielder.interleave\ngleam/yielder interleave","url":"gleam/yielder.html#interleave"},{"doc":"gleam/yielder","title":"intersperse","content":"pub fn intersperse(\n  over yielder: Yielder(a),\n  with elem: a,\n) -&gt; Yielder(a)\n Creates an yielder that yields the given `elem` element\n between elements emitted by the underlying yielder.\n\n ## Examples\n\n \n empty()\n |&gt; intersperse(with: 0)\n |&gt; to_list\n // -&gt; []\n \n\n \n from_list([1])\n |&gt; intersperse(with: 0)\n |&gt; to_list\n // -&gt; [1]\n \n\n \n from_list([1, 2, 3, 4, 5])\n |&gt; intersperse(with: 0)\n |&gt; to_list\n // -&gt; [1, 0, 2, 0, 3, 0, 4, 0, 5]\n \n\nSynonyms:\ngleam/yielder.intersperse\ngleam/yielder intersperse","url":"gleam/yielder.html#intersperse"},{"doc":"gleam/yielder","title":"iterate","content":"pub fn iterate(from initial: a, with f: fn(a) -&gt; a) -&gt; Yielder(a)\n Creates an yielder that infinitely applies a function to a value.\n\n ## Examples\n\n \n iterate(1, fn(n) { n * 3 }) |&gt; take(5) |&gt; to_list\n // -&gt; [1, 3, 9, 27, 81]\n \n\nSynonyms:\ngleam/yielder.iterate\ngleam/yielder iterate","url":"gleam/yielder.html#iterate"},{"doc":"gleam/yielder","title":"last","content":"pub fn last(yielder: Yielder(a)) -&gt; Result(a, Nil)\n Returns the last element in the given yielder.\n\n Returns `Error(Nil)` if the yielder is empty.\n\n This function runs in linear time.\n\n ## Examples\n\n \n empty() |&gt; last\n // -&gt; Error(Nil)\n \n\n \n range(1, 10) |&gt; last\n // -&gt; Ok(10)\n \n\nSynonyms:\ngleam/yielder.last\ngleam/yielder last","url":"gleam/yielder.html#last"},{"doc":"gleam/yielder","title":"length","content":"pub fn length(over yielder: Yielder(a)) -&gt; Int\n Counts the number of elements in the given yielder.\n\n This function has to traverse the entire yielder to count its elements,\n so it runs in linear time.\n\n ## Examples\n\n \n empty() |&gt; length\n // -&gt; 0\n \n\n \n from_list([1, 2, 3, 4]) |&gt; length\n // -&gt; 4\n \n\nSynonyms:\ngleam/yielder.length\ngleam/yielder length","url":"gleam/yielder.html#length"},{"doc":"gleam/yielder","title":"map","content":"pub fn map(\n  over yielder: Yielder(a),\n  with f: fn(a) -&gt; b,\n) -&gt; Yielder(b)\n Creates an yielder from an existing yielder and a transformation function.\n\n Each element in the new yielder will be the result of calling the given\n function on the elements in the given yielder.\n\n This function does not evaluate the elements of the yielder, the\n computation is performed when the yielder is later run.\n\n ## Examples\n\n \n from_list([1, 2, 3])\n |&gt; map(fn(x) { x * 2 })\n |&gt; to_list\n // -&gt; [2, 4, 6]\n \n\nSynonyms:\ngleam/yielder.map\ngleam/yielder map","url":"gleam/yielder.html#map"},{"doc":"gleam/yielder","title":"map2","content":"pub fn map2(\n  yielder1: Yielder(a),\n  yielder2: Yielder(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; Yielder(c)\n Combines two yielders into a single one using the given function.\n\n If an yielder is longer than the other the extra elements are dropped.\n\n This function does not evaluate the elements of the two yielders, the\n computation is performed when the resulting yielder is later run.\n\n ## Examples\n\n \n let first = from_list([1, 2, 3])\n let second = from_list([4, 5, 6])\n map2(first, second, fn(x, y) { x + y }) |&gt; to_list\n // -&gt; [5, 7, 9]\n \n\n \n let first = from_list([1, 2])\n let second = from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n map2(first, second, fn(i, x) { #(i, x) }) |&gt; to_list\n // -&gt; [#(1, &quot;a&quot;), #(2, &quot;b&quot;)]\n \n\nSynonyms:\ngleam/yielder.map2\ngleam/yielder map2","url":"gleam/yielder.html#map2"},{"doc":"gleam/yielder","title":"once","content":"pub fn once(f: fn() -&gt; a) -&gt; Yielder(a)\n Creates an yielder that yields exactly one element provided by calling the given function.\n\n ## Examples\n\n \n once(fn() { 1 }) |&gt; to_list\n // -&gt; [1]\n \n\nSynonyms:\ngleam/yielder.once\ngleam/yielder once","url":"gleam/yielder.html#once"},{"doc":"gleam/yielder","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; Yielder(Int)\n Creates an yielder of ints, starting at a given start int and stepping by\n one to a given end int.\n\n ## Examples\n\n \n range(from: 1, to: 5) |&gt; to_list\n // -&gt; [1, 2, 3, 4, 5]\n \n\n \n range(from: 1, to: -2) |&gt; to_list\n // -&gt; [1, 0, -1, -2]\n \n\n \n range(from: 0, to: 0) |&gt; to_list\n // -&gt; [0]\n \n\nSynonyms:\ngleam/yielder.range\ngleam/yielder range","url":"gleam/yielder.html#range"},{"doc":"gleam/yielder","title":"reduce","content":"pub fn reduce(\n  over yielder: Yielder(a),\n  with f: fn(a, a) -&gt; a,\n) -&gt; Result(a, Nil)\n This function acts similar to fold, but does not take an initial state.\n Instead, it starts from the first yielded element\n and combines it with each subsequent element in turn using the given function.\n The function is called as `f(accumulator, current_element)`.\n\n Returns `Ok` to indicate a successful run, and `Error` if called on an empty yielder.\n\n ## Examples\n\n \n from_list([])\n |&gt; reduce(fn(acc, x) { acc + x })\n // -&gt; Error(Nil)\n \n\n \n from_list([1, 2, 3, 4, 5])\n |&gt; reduce(fn(acc, x) { acc + x })\n // -&gt; Ok(15)\n \n\nSynonyms:\ngleam/yielder.reduce\ngleam/yielder reduce","url":"gleam/yielder.html#reduce"},{"doc":"gleam/yielder","title":"repeat","content":"pub fn repeat(x: a) -&gt; Yielder(a)\n Creates an yielder that returns the same value infinitely.\n\n ## Examples\n\n \n repeat(10)\n |&gt; take(4)\n |&gt; to_list\n // -&gt; [10, 10, 10, 10]\n \n\nSynonyms:\ngleam/yielder.repeat\ngleam/yielder repeat","url":"gleam/yielder.html#repeat"},{"doc":"gleam/yielder","title":"repeatedly","content":"pub fn repeatedly(f: fn() -&gt; a) -&gt; Yielder(a)\n Creates an yielder that yields values created by calling a given function\n repeatedly.\n\n \n repeatedly(fn() { 7 })\n |&gt; take(3)\n |&gt; to_list\n // -&gt; [7, 7, 7]\n \n\nSynonyms:\ngleam/yielder.repeatedly\ngleam/yielder repeatedly","url":"gleam/yielder.html#repeatedly"},{"doc":"gleam/yielder","title":"run","content":"pub fn run(yielder: Yielder(a)) -&gt; Nil\n Evaluates all elements emitted by the given yielder. This function is useful for when\n you wish to trigger any side effects that would occur when evaluating\n the yielder.\n\nSynonyms:\ngleam/yielder.run\ngleam/yielder run","url":"gleam/yielder.html#run"},{"doc":"gleam/yielder","title":"scan","content":"pub fn scan(\n  over yielder: Yielder(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; b,\n) -&gt; Yielder(b)\n Creates an yielder from an existing yielder and a stateful function.\n\n Specifically, this behaves like `fold`, but yields intermediate results.\n\n ## Examples\n\n \n // Generate a sequence of partial sums\n from_list([1, 2, 3, 4, 5])\n |&gt; scan(from: 0, with: fn(acc, el) { acc + el })\n |&gt; to_list\n // -&gt; [1, 3, 6, 10, 15]\n \n\nSynonyms:\ngleam/yielder.scan\ngleam/yielder scan","url":"gleam/yielder.html#scan"},{"doc":"gleam/yielder","title":"single","content":"pub fn single(elem: a) -&gt; Yielder(a)\n Creates an yielder that yields the given element exactly once.\n\n ## Examples\n\n \n single(1) |&gt; to_list\n // -&gt; [1]\n \n\nSynonyms:\ngleam/yielder.single\ngleam/yielder single","url":"gleam/yielder.html#single"},{"doc":"gleam/yielder","title":"sized_chunk","content":"pub fn sized_chunk(\n  over yielder: Yielder(a),\n  into count: Int,\n) -&gt; Yielder(List(a))\n Creates an yielder that emits chunks of given size.\n\n If the last chunk does not have `count` elements, it is yielded\n as a partial chunk, with less than `count` elements.\n\n For any `count` less than 1 this function behaves as if it was set to 1.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 5, 6])\n |&gt; sized_chunk(into: 2)\n |&gt; to_list\n // -&gt; [[1, 2], [3, 4], [5, 6]]\n \n\n \n from_list([1, 2, 3, 4, 5, 6, 7, 8])\n |&gt; sized_chunk(into: 3)\n |&gt; to_list\n // -&gt; [[1, 2, 3], [4, 5, 6], [7, 8]]\n \n\nSynonyms:\ngleam/yielder.sized_chunk\ngleam/yielder sized_chunk","url":"gleam/yielder.html#sized_chunk"},{"doc":"gleam/yielder","title":"step","content":"pub fn step(yielder: Yielder(a)) -&gt; Step(a, Yielder(a))\n Eagerly accesses the first value of an yielder, returning a `Next`\n that contains the first value and the rest of the yielder.\n\n If called on an empty yielder, `Done` is returned.\n\n ## Examples\n\n \n let assert Next(first, rest) = from_list([1, 2, 3, 4]) |&gt; step\n\n first\n // -&gt; 1\n\n rest |&gt; to_list\n // -&gt; [2, 3, 4]\n \n\n \n empty() |&gt; step\n // -&gt; Done\n \n\nSynonyms:\ngleam/yielder.step\ngleam/yielder step","url":"gleam/yielder.html#step"},{"doc":"gleam/yielder","title":"take","content":"pub fn take(\n  from yielder: Yielder(a),\n  up_to desired: Int,\n) -&gt; Yielder(a)\n Creates an yielder that only yields the first `desired` elements.\n\n If the yielder does not have enough elements all of them are yielded.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4, 5])\n |&gt; take(up_to: 3)\n |&gt; to_list\n // -&gt; [1, 2, 3]\n \n\n \n from_list([1, 2])\n |&gt; take(up_to: 3)\n |&gt; to_list\n // -&gt; [1, 2]\n \n\nSynonyms:\ngleam/yielder.take\ngleam/yielder take","url":"gleam/yielder.html#take"},{"doc":"gleam/yielder","title":"take_while","content":"pub fn take_while(\n  in yielder: Yielder(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Yielder(a)\n Creates an yielder that yields elements while the predicate returns `True`.\n\n ## Examples\n\n \n from_list([1, 2, 3, 2, 4])\n |&gt; take_while(satisfying: fn(x) { x &lt; 3 })\n |&gt; to_list\n // -&gt; [1, 2]\n \n\nSynonyms:\ngleam/yielder.take_while\ngleam/yielder take_while","url":"gleam/yielder.html#take_while"},{"doc":"gleam/yielder","title":"to_list","content":"pub fn to_list(yielder: Yielder(a)) -&gt; List(a)\n Evaluates an yielder and returns all the elements as a list.\n\n If called on an yielder of infinite length then this function will never\n return.\n\n ## Examples\n\n \n from_list([1, 2, 3])\n |&gt; map(fn(x) { x * 2 })\n |&gt; to_list\n // -&gt; [2, 4, 6]\n \n\nSynonyms:\ngleam/yielder.to_list\ngleam/yielder to_list","url":"gleam/yielder.html#to_list"},{"doc":"gleam/yielder","title":"transform","content":"pub fn transform(\n  over yielder: Yielder(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; Step(c, b),\n) -&gt; Yielder(c)\n Creates an yielder from an existing yielder\n and a stateful function that may short-circuit.\n\n `f` takes arguments `acc` for current state and `el` for current element from underlying yielder,\n and returns either `Next` with yielded element and new state value, or `Done` to halt the yielder.\n\n ## Examples\n\n Approximate implementation of `index` in terms of `transform`:\n\n \n from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n |&gt; transform(0, fn(i, el) { Next(#(i, el), i + 1) })\n |&gt; to_list\n // -&gt; [#(0, &quot;a&quot;), #(1, &quot;b&quot;), #(2, &quot;c&quot;)]\n \n\nSynonyms:\ngleam/yielder.transform\ngleam/yielder transform","url":"gleam/yielder.html#transform"},{"doc":"gleam/yielder","title":"try_fold","content":"pub fn try_fold(\n  over yielder: Yielder(a),\n  from initial: b,\n  with f: fn(b, a) -&gt; Result(b, c),\n) -&gt; Result(b, c)\n A variant of fold that might fail.\n\n The folding function should return `Result(accumulator, error)`.\n If the returned value is `Ok(accumulator)` try_fold will try the next value in the yielder.\n If the returned value is `Error(error)` try_fold will stop and return that error.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; try_fold(0, fn(acc, i) {\n   case i &lt; 3 {\n     True -&gt; Ok(acc + i)\n     False -&gt; Error(Nil)\n   }\n })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/yielder.try_fold\ngleam/yielder try_fold","url":"gleam/yielder.html#try_fold"},{"doc":"gleam/yielder","title":"unfold","content":"pub fn unfold(\n  from initial: a,\n  with f: fn(a) -&gt; Step(b, a),\n) -&gt; Yielder(b)\n Creates an yielder from a given function and accumulator.\n\n The function is called on the accumulator and returns either `Done`,\n indicating the yielder has no more elements, or `Next` which contains a\n new element and accumulator. The element is yielded by the yielder and the\n new accumulator is used with the function to compute the next element in\n the sequence.\n\n ## Examples\n\n \n unfold(from: 5, with: fn(n) {\n  case n {\n    0 -&gt; Done\n    n -&gt; Next(element: n, accumulator: n - 1)\n  }\n })\n |&gt; to_list\n // -&gt; [5, 4, 3, 2, 1]\n \n\nSynonyms:\ngleam/yielder.unfold\ngleam/yielder unfold","url":"gleam/yielder.html#unfold"},{"doc":"gleam/yielder","title":"yield","content":"pub fn yield(element: a, next: fn() -&gt; Yielder(a)) -&gt; Yielder(a)\n Add a new element to the start of an yielder.\n\n This function is for use with `use` expressions, to replicate the behaviour\n of the `yield` keyword found in other languages.\n\n ## Examples\n\n \n let yielder = {\n   use &lt;- yield(1)\n   use &lt;- yield(2)\n   use &lt;- yield(3)\n   empty()\n }\n\n yielder |&gt; to_list\n // -&gt; [1, 2, 3]\n \n\nSynonyms:\ngleam/yielder.yield\ngleam/yielder yield","url":"gleam/yielder.html#yield"},{"doc":"gleam/yielder","title":"zip","content":"pub fn zip(\n  left: Yielder(a),\n  right: Yielder(b),\n) -&gt; Yielder(#(a, b))\n Zips two yielders together, emitting values from both\n until the shorter one runs out.\n\n ## Examples\n\n \n from_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n |&gt; zip(range(20, 30))\n |&gt; to_list\n // -&gt; [#(&quot;a&quot;, 20), #(&quot;b&quot;, 21), #(&quot;c&quot;, 22)]\n \n\nSynonyms:\ngleam/yielder.zip\ngleam/yielder zip","url":"gleam/yielder.html#zip"},{"doc":"gleam/yielder","title":"gleam/yielder","content":"","url":"gleam/yielder.html"}]);